ClientData

Trait ClientData 

pub trait ClientData:
    Any
    + Send
    + Sync {
    // Provided methods
    fn initialized(&self, _client_id: ClientId) { ... }
    fn disconnected(&self, _client_id: ClientId, _reason: DisconnectReason) { ... }
    fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error> { ... }
}
A trait representing your data associated to a client

Provided Methods

fn initialized(&self, _client_id: ClientId)

Notification that the client was initialized

fn disconnected(&self, _client_id: ClientId, _reason: DisconnectReason)

Notification that the client is disconnected

fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Helper for forwarding a Debug implementation of your ClientData type

By default will just print GlobalHandler { ... }